==> calligra_2.8.1-1.orig.tar.xz: calligra-2.8.1/filters/words/msword-odf/mswordodfimport.h <==
/* This file is part of the Calligra project
   Copyright (C) 2002 Werner Trobin <trobin@kde.org>
   Copyright (C) 2002 David Faure <faure@kde.org>
   Copyright (C) 2008 Benjamin Cail <cricketc@gmail.com>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the Library GNU General Public
   version 2 of the License, or (at your option) version 3 or,
   at the discretion of KDE e.V (which shall act as a proxy as in
   section 14 of the GPLv3), any later version..

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef MSWORDODFIMPORT_H
#define MSWORDODFIMPORT_H

#include <KoFilter.h>

#include <QByteArray>
#include <QVariantList>

class MSWordOdfImport : public KoFilter
{
    Q_OBJECT
public:
    MSWordOdfImport(QObject* parent, const QVariantList&);
    virtual ~MSWordOdfImport();

    virtual KoFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to);

    void setProgress(const int percent);

private:
    // checks from FIB if document is encrypted
    bool isEncrypted(const QString &inputfile);


};

#endif // MSWORDODFIMPORT_H

==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/filters/words/msword-odf/mswordodfimport.h <==
/* This file is part of the Calligra project
   Copyright (C) 2002 Werner Trobin <trobin@kde.org>
   Copyright (C) 2002 David Faure <faure@kde.org>
   Copyright (C) 2008 Benjamin Cail <cricketc@gmail.com>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the Library GNU General Public
   version 2 of the License, or (at your option) version 3 or,
   at the discretion of KDE e.V (which shall act as a proxy as in
   section 14 of the GPLv3), any later version..

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef MSWORDODFIMPORT_H
#define MSWORDODFIMPORT_H

#include <KoFilter.h>

#include <QByteArray>
#include <QVariantList>

class MSWordOdfImport : public KoFilter
{
    Q_OBJECT
public:
    MSWordOdfImport(QObject* parent, const QVariantList&);
    ~MSWordOdfImport() override;

    KoFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to) override;

    void setProgress(const int percent);

private:
    // checks from FIB if document is encrypted
    bool isEncrypted(const QString &inputfile);


};

#endif // MSWORDODFIMPORT_H
